﻿# Correo.PublishedLanguage

[Correo](https://lab.code-rove.com/gitea/tudor.stanciu/correo) is a .NET service for programmatically sending emails. Communication with this service is available through two channels:

- **HTTP** (via REST API)
- **Pub/Sub Messaging** (via NATS)

**Correo.PublishedLanguage** is a NuGet package that encapsulates the published language of **Correo**. It streamlines communication with the server in a .NET environment by providing essential **DTOs (Data Transfer Objects)** and constants. This package equips developers with the necessary tools to integrate the API's functionality into their applications using clear and consistent data structures.

## Key Features

- Provides pre-defined DTOs for seamless communication with Correo.
- Includes constants for maintaining consistency across applications.
- Supports both HTTP and Pub/Sub messaging channels.
- Simplifies integration with Correo's email service.

By leveraging **Correo.PublishedLanguage**, developers can effortlessly incorporate email-sending functionalities into their applications, improving user notifications and communication workflows.

## Package Repository

You can install **Correo.PublishedLanguage** from my self-hosted NuGet feed: [https://lab.code-rove.com/public-nuget-server/](https://lab.code-rove.com/public-nuget-server/)

## Installation

### Visual Studio

#### NuGet.config File

To integrate the package, configure your Visual Studio solution with the following `NuGet.config` file:

```xml
<?xml version="1.0" encoding="utf-8"?>
<configuration>
  <packageSources>
    <clear />
    <add key="nuget.org" value="https://api.nuget.org/v3/index.json" />
    <add key="lab.nuget" value="https://lab.code-rove.com/public-nuget-server/v3/index.json" />
  </packageSources>
</configuration>
```

Add this `NuGet.config` file to your solution directory, or alternatively, configure the new NuGet feed in the NuGet Package Manager within Visual Studio. After completing this setup, you can install `Correo.PublishedLanguage` using the NuGet Package Manager.

### CLI

To install the package via the command line, run the following command in a terminal within your .NET project directory:

```bash
 dotnet add package Correo.PublishedLanguage --source https://lab.code-rove.com/public-nuget-server/v3/index.json
```

## Usage

Once installed, you can use the DTOs and constants provided by the package to communicate effectively with Correo’s API. Here's an example of how to use a DTO in your application:

```csharp
using NetworkResurrector.Server.PublishedLanguage;

// Example usage of a DTO from the package
var cmd = new SendEmail()
{
    Subject = "Hello from Correo",
    Body = "Hello from Correo",
    IsBodyHtml = false,
    To = [ "user@homelab.com" ]
};

await _messageBusPublisher.PublishAsync(cmd);

// Your logic here
```

This package simplifies email integration within your .NET applications, ensuring efficient and reliable messaging capabilities.
